<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>ئۇچۇش ھالىتىنى ئېچىش</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation> ئۇچۇش ھالىتىنى تاقاش</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تاقاق</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>ئۇچۇش ھالىتى تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>ئۈسكۈنەم</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>كۆكچىشنى ئېچىش</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ئۇلاندى</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>ئۇلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation> %1 غا ئۇلاندى</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>تاقاش</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>يورۇقلۇق</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>كۆرستىش تەڭشەكلىرى</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>كۆرستىش تەڭشەكلىرى</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>يورۇقلۇق</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>كۈن</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>دۈشەنبە</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>سەيشەنبە</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>چارشەنبە</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>پەيشەنبە</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>جۈمە</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>شەنبە</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇلۇشى قوشۇش</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>چېسىلا ۋە ۋاقىت</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 سائەتلىك</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 سائەتلىك</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>ۋاقىت تەڭشىكى</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>كالېندارنى ئېچىش</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>دۈشەنبە</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>سەيشەنبە</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>چارشەنبە</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>پەيشەنبە</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>جۈمە</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>شەنبە</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>يەكشەنبە</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>دۈشەنبە</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>سەيشەنبە</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>چارشەنبە</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>پەيشەنبە</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>جۈمە</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>شەنبە</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>يەكشەنبە</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>باشقا ئۈسكۈنىلەر</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>دەخلىسىز ھالەت</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>دەخلىسىز ھالەت تەڭشىكى</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تاقاق</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>دەخلىسىز ھالەتنى ئېچىش</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>دەخلىسىز ھالەتنى تاقاش</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>دەخلىسىز ھالەت</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>كۆز ئاسراش ھالىتى</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>كۆز ئاسراش ھالىتىنى ئېچىش</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>كۆز ئاسراش ھالىتىنى تاقاش</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>كۆرستىش تەڭشەكلىرى</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>كۆز ئاسراش ھالىتى</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>ئۇسلۇب</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>سۇس رەڭ</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>قېنىق رەڭ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>كۆز ئاسراس ھالىتىنى تاقاش</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>كۆز ئاسراس ھالىتىنى ئېچىش</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>كۆرستىش تەڭشەكلىرى</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>ئۇسلۇب: سۇس رەڭ</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>ئۇسلۇب: قېنىق رەڭ</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>ئۇسلۇب: ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>كۆرۈنۈش ئۈنۈمى</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>سۇس رەڭ</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>قېنىق رەڭ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ئاپتوماتىك</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>ئۇسلۇب</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>يېڭى ئۇچۇر يوق</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>ئۇقتۇرۇش تەڭشىكى</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>پارچە ئۇقتۇرۇش</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>تىنچ ھالەتنى تاقاش</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>تىنچ ھالەتنى ئېچىش</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>ئۇقتۇرۇش</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ئېكران كۇنۇپكىسى</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>يۇقىرى ئىقتىدار ھالىتى</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>تەڭپۇڭ ھالەت</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>ئېنېرگىيە تېجەش ھالىتى</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>توك مەنبە</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>توك %1 قالدى، %2 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>توك %1 قالدى، %2 سائەت %3 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ%1، يەنە %2 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ%1، يەنە %2 سائەت %3 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>توكى%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>زەرەتلەۋاتىدۇ%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>توك%1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>توك%1، توشتى</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>توك %1 قالدى، توك قاچىلانمىدى</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>باتارېيە</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>توك قاچىلىنىۋاتىدۇ، مۆلچەردىكى توك قاچىلاش ۋاقتى ھېسابلىنىۋاتىدۇ... </translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>مۆلچەردىكى ئىشلىتىشكە يېتىدىغان ۋاقىت ھېسابلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>تەخمىنەن يەنە %1 يېتىدۇ</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>تەخمىنەن يەنە %1 سائەت %2 يېتىدۇ</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>توك قاچىلانمىغان</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>توك قاچىلىنىپ بولدى</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ، يەنە %1 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ، يەنە %1 سائەت %2 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>توك %1 قالدى، %2 سائەت يېتىدۇ</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation> يەنە %1 سائەت يېتىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ%1، يەنە %2 سائەتتە توشىدۇ</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>توك قاچىلىنىۋاتىدۇ، يەنە %1 سائەتتە توشىدۇ</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>توك مەنبە تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>مۇزىكا</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئېسىپ قويۇش</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇخلاش ھالىتى</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ئېكران قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تىزىمدىن چېكىنىش</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>يېڭىلاش ۋە تاقاش</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>يېڭىلاش ۋە قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>ئىشلەتكۈچى ئالماشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>بۈگۈن</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>دېھقانلار كالېندارى</translation>
    </message>
    <message>
        <source>y</source>
        <translation>-يىل</translation>
    </message>
    <message>
        <source>m</source>
        <translation>-ئاينىڭ</translation>
    </message>
    <message>
        <source>d</source>
        <translation>-كۈنى</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>دۈشەنبە</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>سەيشەنبە</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>چارشەنبە</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>پەيشەنبە</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>جۈمە</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>شەنبە</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>يەكشەنبە</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>1-ئاي</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>2-ئاي</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>3-ئاي</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>4-ئاي</translation>
    </message>
    <message>
        <source>May</source>
        <translation>5-ئاي</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>6-ئاي</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>7-ئاي</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>8-ئاي</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>9-ئاي</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>10-ئاي</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>11-ئاي</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>12-ئاي</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>كالېندارنى ئېچىش</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>دۈشەنبە</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>سەيشەنبە</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>چارشەنبە</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>پەيشەنبە</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>جۈمە</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>شەنبە</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>يەكشەنبە</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>ئاۋاز</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>چىقىرىش</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ئاۋاز تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ئاۋاز</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>ئاۋازلىق</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ئاۋازسىز</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ئاۋاز تەڭشىكى</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>ئاۋازسىز چىقىرىش ئۈسكۈنىلىرى</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>ئاۋاز %1</translation>
    </message>
</context>
</TS>